# Pangsit(py)

Pangsit(py) is my starter pack framework represented in Python to deal with learning computing such as Machine/Deep Learning,
Data Science, etc. Of course I don't built it from scratch. I use some existing modules such as `keras`, 
`tensorflow`, `scikit`, etc, to help me doing Machine/Deep Learning jobs.

> I'll create a documentation for this later.

### Requirements

- Python >=3.6 (tested on 3.7)

### Installation

```shell script
pip3 install pangsitpy
```

### Get the latest version

This package updates frequently, so make sure you're using the latest version
for better logical processes or to get new modules to work with.
You can read the
[CHANGELOG.md](https://github.com/dalikewara/pangsitpy/blob/master/CHANGELOG.md)

```shell script
pip3 install pangsitpy --upgrade
```

### Manual usage

You can clone or download the package through git remote. This package requires modules listed in `requirements.txt`.
If you want to install modules from `requirements.txt`, I would highly suggest to use
Virtual Environment because it contains modules with it's specific version. You can learn about Virtual Environment on 
[https://docs.python.org/3/tutorial/venv.html](https://docs.python.org/3/tutorial/venv.html)

# Release

### Changelog
[https://github.com/dalikewara/pangsitpy/blob/master/CHANGELOG.md](https://github.com/dalikewara/pangsitpy/blob/master/CHANGELOG.md).

### Credits
Copyright &copy; 2020 [Dali Kewara](https://www.dalikewara.com).

### License
[MIT License](https://github.com/dalikewara/pangsitpy/blob/master/LICENSE)